package
module
Version:
v1.0.9
Opens a new window with list of versions in this module.
Published: Sep 10, 2021
License: OSL-3.0
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
JA3
Impersonating JA3 signatures
https://godocs.io/github.com/89z/ja3
{8896468359a279a05de2651c5021ac6f 3061092 python-requests/2.25.1}
panic: extension does not exist "49"
SSLVersion
771
Cipher
4866-4867-4865-49196-49200-49195-49199-52393-52392-159-158-52394-49327-49325-49326-49324-49188-49192-49187-49191-49162-49172-49161-49171-49315-49311-49314-49310-107-103-57-51-157-156-49313-49309-49312-49308-61-60-53-47-255
SSLExtension
0-11-10-16-22-23-49-13-43-45-51-21
EllipticCurve
29-23-1035-25-24
EllipticCurvePointFormat
0-1-2
Spec
Documentation
¶
const (
AllHashes = "https://ja3er.com/getAllHashesJson"
AllUas = "https://ja3er.com/getAllUasJson"
)
NewTransport creates an http.Transport which mocks the given JA3 signature
when HTTPS is used.
Parse creates a ClientHelloSpec based on a JA3 string.
type JA3er struct {
Users []struct {
MD5 string
Count int
Agent string `json:"User-Agent"`
}
Hashes []struct {
MD5 string
JA3 string
}
}
func (j JA3er) SortUsers()
Source Files
¶
Click to show internal directories.
Click to hide internal directories.