package
module
Version:
v1.0.5
Opens a new window with list of versions in this module.
Published: Sep 10, 2021
License: OSL-3.0
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
JA3
Impersonating JA3 signatures
https://godocs.io/github.com/89z/ja3
4865-49196-49200-49195-49199-52393-52392-159-158-52394-49327-49325-49326-49324-49188-49192-49187-49191-49162-49172-49161-49171-49315-49311-49314-49310-107-103-57-51-157-156-49313-49309-49312-49308-61-60-53-47-255
Documentation
¶
const AllUas = "https://ja3er.com/getAllUasJson"
NewTransport creates an http.Transport which mocks the given JA3 signature
when HTTPS is used.
Parse creates a ClientHelloSpec based on a JA3 string.
type Agent struct {
LastSeen string `json:"Last_seen"`
MD5 string
UserAgent string `json:"User-Agent"`
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.