ja3

package module
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 9, 2021 License: OSL-3.0 Imports: 7 Imported by: 0

README

JA3

Impersonating JA3 signatures

https://godocs.io/github.com/89z/ja3

Documentation

Index

Constants

const (
	// ChromeAuto mocks Chrome 78
	ChromeAuto = "769,47–53–5–10–49161–49162–49171–49172–50–56–19–4,0–10–11,23–24–25,0"
	// SafariAuto mocks Safari 604.1
	SafariAuto = "" /* 191-byte string literal not displayed */
)

Variables

This section is empty.

Functions

func NewTransport

func NewTransport(ja3 string) (*http.Transport, error)

NewTransport creates an http.Transport which mocks the given JA3 signature when HTTPS is used

func NewTransportWithConfig

func NewTransportWithConfig(ja3 string, config *tls.Config) (*http.Transport, error)

NewTransportWithConfig creates an http.Transport object given a utls.Config

Types

type ErrExtensionNotExist

type ErrExtensionNotExist string

ErrExtensionNotExist is returned when an extension is not supported by the library

func (ErrExtensionNotExist) Error

func (e ErrExtensionNotExist) Error() string

Error is the error value which contains the extension that does not exist

type JA3Client

type JA3Client struct {
	*http.Client
	*tls.Config
}

JA3Client contains is similar to http.Client

func NewWithString

func NewWithString(ja3 string) (*JA3Client, error)

NewWithString creates a JA3 client with the specified JA3 string

Jump to