Documentation
¶
Index ¶
Constants ¶
const ( // ChromeAuto mocks Chrome 78 ChromeAuto = "769,47–53–5–10–49161–49162–49171–49172–50–56–19–4,0–10–11,23–24–25,0" // SafariAuto mocks Safari 604.1 SafariAuto = "" /* 191-byte string literal not displayed */ )
Variables ¶
This section is empty.
Functions ¶
func NewTransport ¶
NewTransport creates an http.Transport which mocks the given JA3 signature when HTTPS is used
Types ¶
type ErrExtensionNotExist ¶
type ErrExtensionNotExist string
ErrExtensionNotExist is returned when an extension is not supported by the library
func (ErrExtensionNotExist) Error ¶
func (e ErrExtensionNotExist) Error() string
Error is the error value which contains the extension that does not exist
Click to show internal directories.
Click to hide internal directories.